@@ -31,7 +31,7 @@ print = partial(print,flush=True)
 DSQ_DOT="_yx_dsq_dot_yx_"
 
 def _json(ds) :
-    return json.dumps(ds,indent=2,sort_keys=True)
+    return json.dumps(ds,indent=2,sort_keys=True,default=str)
 #def _xml(ds) :
 #    import xml.dom.minidom as dom
 #    import dicttoxml
@@ -271,7 +271,7 @@ def dsq_main():
                 if _x_args.rows != 2**30 :
                     res = json.loads(res)
                     res = shrink_list(res)
-                    res = json.dumps(res,indent=2,sort_keys=True)
+                    res = json.dumps(res,indent=2,default=str,sort_keys=True)
                 xprint(highlight(res,JsonLexer(),Terminal256Formatter()))
                 return
             except :
@@ -305,14 +305,14 @@ def dsq_main():
                 try :
                     if _x_args.plain :
                         if _x_args.compact :
-                            xprint(json.dumps(res))
+                            xprint(json.dumps(res,default=str))
                         else :
-                            xprint(json.dumps(res,indent=2))
+                            xprint(json.dumps(res,indent=2,default=str))
                     else :
                         if _x_args.compact :
-                            xprint(highlight(json.dumps(res),JsonLexer(),Terminal256Formatter()))
+                            xprint(highlight(json.dumps(res,default=str),JsonLexer(),Terminal256Formatter()))
                         else :
-                            xprint(highlight(json.dumps(res,indent=2),JsonLexer(),Terminal256Formatter()))
+                            xprint(highlight(json.dumps(res,indent=2,default=str),JsonLexer(),Terminal256Formatter()))
                 except :
                     xprint(str(res))
 
@@ -553,7 +553,7 @@ def dsq_main():
 
     if _x_args.debug >= 2 :
         print_err("# data loaded :",lvl=1)
-        print_err(json.dumps(_,indent=2))
+        print_err(json.dumps(_,indent=2,default=str))
 
     _x_key_dict = defaultdict(set)
     collect_keys(_,dt=_x_key_dict)
